@@ -1,12 +1,9 @@
-# coding: utf-8
 import datetime
 import json
 import time
-import warnings
 
-from unittest2 import SkipTest
+import pytest
 
-from pymysql import util
 import pymysql.cursors
 from pymysql.tests import base
 from pymysql.err import ProgrammingError
@@ -20,23 +17,46 @@ class TestConversion(base.PyMySQLTestCase):
         """ test every data type """
         conn = self.connect()
         c = conn.cursor()
-        c.execute("create table test_datatypes (b bit, i int, l bigint, f real, s varchar(32), u varchar(32), bb blob, d date, dt datetime, ts timestamp, td time, t time, st datetime)")
+        c.execute(
+            "create table test_datatypes (b bit, i int, l bigint, f real, s varchar(32), u varchar(32), bb blob, d date, dt datetime, ts timestamp, td time, t time, st datetime)"
+        )
         try:
             # insert values
 
-            v = (True, -3, 123456789012, 5.7, "hello'\" world", u"Espa\xc3\xb1ol", "binary\x00data".encode(conn.encoding), datetime.date(1988,2,2), datetime.datetime(2014, 5, 15, 7, 45, 57), datetime.timedelta(5,6), datetime.time(16,32), time.localtime())
-            c.execute("insert into test_datatypes (b,i,l,f,s,u,bb,d,dt,td,t,st) values (%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s)", v)
+            v = (
+                True,
+                -3,
+                123456789012,
+                5.7,
+                "hello'\" world",
+                "Espa\xc3\xb1ol",
+                "binary\x00data".encode(conn.encoding),
+                datetime.date(1988, 2, 2),
+                datetime.datetime(2014, 5, 15, 7, 45, 57),
+                datetime.timedelta(5, 6),
+                datetime.time(16, 32),
+                time.localtime(),
+            )
+            c.execute(
+                "insert into test_datatypes (b,i,l,f,s,u,bb,d,dt,td,t,st) values (%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s)",
+                v,
+            )
             c.execute("select b,i,l,f,s,u,bb,d,dt,td,t,st from test_datatypes")
             r = c.fetchone()
-            self.assertEqual(util.int2byte(1), r[0])
+            self.assertEqual(b"\x01", r[0])
             self.assertEqual(v[1:10], r[1:10])
-            self.assertEqual(datetime.timedelta(0, 60 * (v[10].hour * 60 + v[10].minute)), r[10])
+            self.assertEqual(
+                datetime.timedelta(0, 60 * (v[10].hour * 60 + v[10].minute)), r[10]
+            )
             self.assertEqual(datetime.datetime(*v[-1][:6]), r[-1])
 
             c.execute("delete from test_datatypes")
 
             # check nulls
-            c.execute("insert into test_datatypes (b,i,l,f,s,u,bb,d,dt,td,t,st) values (%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s)", [None] * 12)
+            c.execute(
+                "insert into test_datatypes (b,i,l,f,s,u,bb,d,dt,td,t,st) values (%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s)",
+                [None] * 12,
+            )
             c.execute("select b,i,l,f,s,u,bb,d,dt,td,t,st from test_datatypes")
             r = c.fetchone()
             self.assertEqual(tuple([None] * 12), r)
@@ -45,11 +65,15 @@ class TestConversion(base.PyMySQLTestCase):
 
             # check sequences type
             for seq_type in (tuple, list, set, frozenset):
-                c.execute("insert into test_datatypes (i, l) values (2,4), (6,8), (10,12)")
-                seq = seq_type([2,6])
-                c.execute("select l from test_datatypes where i in %s order by i", (seq,))
+                c.execute(
+                    "insert into test_datatypes (i, l) values (2,4), (6,8), (10,12)"
+                )
+                seq = seq_type([2, 6])
+                c.execute(
+                    "select l from test_datatypes where i in %s order by i", (seq,)
+                )
                 r = c.fetchall()
-                self.assertEqual(((4,),(8,)), r)
+                self.assertEqual(((4,), (8,)), r)
                 c.execute("delete from test_datatypes")
 
         finally:
@@ -61,9 +85,12 @@ class TestConversion(base.PyMySQLTestCase):
         c = conn.cursor()
         c.execute("create table test_dict (a integer, b integer, c integer)")
         try:
-            c.execute("insert into test_dict (a,b,c) values (%(a)s, %(b)s, %(c)s)", {"a":1,"b":2,"c":3})
+            c.execute(
+                "insert into test_dict (a,b,c) values (%(a)s, %(b)s, %(c)s)",
+                {"a": 1, "b": 2, "c": 3},
+            )
             c.execute("select a,b,c from test_dict")
-            self.assertEqual((1,2,3), c.fetchone())
+            self.assertEqual((1, 2, 3), c.fetchone())
         finally:
             c.execute("drop table test_dict")
 
@@ -96,7 +123,8 @@ class TestConversion(base.PyMySQLTestCase):
         data = bytes(bytearray(range(255)))
         conn = self.connect()
         self.safe_create_table(
-            conn, "test_binary", "create table test_binary (b binary(255))")
+            conn, "test_binary", "create table test_binary (b binary(255))"
+        )
 
         with conn.cursor() as c:
             c.execute("insert into test_binary (b) values (_binary %s)", (data,))
@@ -107,8 +135,7 @@ class TestConversion(base.PyMySQLTestCase):
         """test blob data"""
         data = bytes(bytearray(range(256)) * 4)
         conn = self.connect()
-        self.safe_create_table(
-            conn, "test_blob", "create table test_blob (b blob)")
+        self.safe_create_table(conn, "test_blob", "create table test_blob (b blob)")
 
         with conn.cursor() as c:
             c.execute("insert into test_blob (b) values (_binary %s)", (data,))
@@ -120,38 +147,41 @@ class TestConversion(base.PyMySQLTestCase):
         conn = self.connect()
         c = conn.cursor()
         c.execute("select null,''")
-        self.assertEqual((None,u''), c.fetchone())
+        self.assertEqual((None, ""), c.fetchone())
         c.execute("select '',null")
-        self.assertEqual((u'',None), c.fetchone())
+        self.assertEqual(("", None), c.fetchone())
 
     def test_timedelta(self):
         """ test timedelta conversion """
         conn = self.connect()
         c = conn.cursor()
-        c.execute("select time('12:30'), time('23:12:59'), time('23:12:59.05100'), time('-12:30'), time('-23:12:59'), time('-23:12:59.05100'), time('-00:30')")
-        self.assertEqual((datetime.timedelta(0, 45000),
-                          datetime.timedelta(0, 83579),
-                          datetime.timedelta(0, 83579, 51000),
-                          -datetime.timedelta(0, 45000),
-                          -datetime.timedelta(0, 83579),
-                          -datetime.timedelta(0, 83579, 51000),
-                          -datetime.timedelta(0, 1800)),
-                         c.fetchone())
+        c.execute(
+            "select time('12:30'), time('23:12:59'), time('23:12:59.05100'), time('-12:30'), time('-23:12:59'), time('-23:12:59.05100'), time('-00:30')"
+        )
+        self.assertEqual(
+            (
+                datetime.timedelta(0, 45000),
+                datetime.timedelta(0, 83579),
+                datetime.timedelta(0, 83579, 51000),
+                -datetime.timedelta(0, 45000),
+                -datetime.timedelta(0, 83579),
+                -datetime.timedelta(0, 83579, 51000),
+                -datetime.timedelta(0, 1800),
+            ),
+            c.fetchone(),
+        )
 
     def test_datetime_microseconds(self):
         """ test datetime conversion w microseconds"""
 
         conn = self.connect()
         if not self.mysql_server_is(conn, (5, 6, 4)):
-            raise SkipTest("target backend does not support microseconds")
+            pytest.skip("target backend does not support microseconds")
         c = conn.cursor()
         dt = datetime.datetime(2013, 11, 12, 9, 9, 9, 123450)
         c.execute("create table test_datetime (id int, ts datetime(6))")
         try:
-            c.execute(
-                "insert into test_datetime values (%s, %s)",
-                (1, dt)
-            )
+            c.execute("insert into test_datetime values (%s, %s)", (1, dt))
             c.execute("select ts from test_datetime")
             self.assertEqual((dt,), c.fetchone())
         finally:
@@ -164,7 +194,7 @@ class TestCursor(base.PyMySQLTestCase):
     # compatible with the DB-API 2.0 spec and has not broken
     # any unit tests for anything we've tried.
 
-    #def test_description(self):
+    # def test_description(self):
     #    """ test description attribute """
     #    # result is from MySQLdb module
     #    r = (('Host', 254, 11, 60, 60, 0, 0),
@@ -229,22 +259,22 @@ class TestCursor(base.PyMySQLTestCase):
         conn = self.connect()
         c = conn.cursor()
         try:
-            c.execute('create table test_aggregates (i integer)')
+            c.execute("create table test_aggregates (i integer)")
             for i in range(0, 10):
-                c.execute('insert into test_aggregates (i) values (%s)', (i,))
-            c.execute('select sum(i) from test_aggregates')
-            r, = c.fetchone()
-            self.assertEqual(sum(range(0,10)), r)
+                c.execute("insert into test_aggregates (i) values (%s)", (i,))
+            c.execute("select sum(i) from test_aggregates")
+            (r,) = c.fetchone()
+            self.assertEqual(sum(range(0, 10)), r)
         finally:
-            c.execute('drop table test_aggregates')
+            c.execute("drop table test_aggregates")
 
     def test_single_tuple(self):
         """ test a single tuple """
         conn = self.connect()
         c = conn.cursor()
         self.safe_create_table(
-            conn, 'mystuff',
-            "create table mystuff (id integer primary key)")
+            conn, "mystuff", "create table mystuff (id integer primary key)"
+        )
         c.execute("insert into mystuff (id) values (1)")
         c.execute("insert into mystuff (id) values (2)")
         c.execute("select id from mystuff where id in %s", ((1,),))
@@ -256,17 +286,21 @@ class TestCursor(base.PyMySQLTestCase):
         args["charset"] = "utf8mb4"
         conn = pymysql.connect(**args)
         if not self.mysql_server_is(conn, (5, 7, 0)):
-            raise SkipTest("JSON type is not supported on MySQL <= 5.6")
+            pytest.skip("JSON type is not supported on MySQL <= 5.6")
 
-        self.safe_create_table(conn, "test_json", """\
+        self.safe_create_table(
+            conn,
+            "test_json",
+            """\
 create table test_json (
     id int not null,
     json JSON not null,
     primary key (id)
-);""")
+);""",
+        )
         cur = conn.cursor()
 
-        json_str = u'{"hello": "こんにちは"}'
+        json_str = '{"hello": "こんにちは"}'
         cur.execute("INSERT INTO test_json (id, `json`) values (42, %s)", (json_str,))
         cur.execute("SELECT `json` from `test_json` WHERE `id`=42")
         res = cur.fetchone()[0]
@@ -287,16 +321,20 @@ class TestBulkInserts(base.PyMySQLTestCase):
         c = conn.cursor(self.cursor_type)
 
         # create a table ane some data to query
-        self.safe_create_table(conn, 'bulkinsert', """\
+        self.safe_create_table(
+            conn,
+            "bulkinsert",
+            """\
 CREATE TABLE bulkinsert
 (
-id int(11),
+id int,
 name char(20),
 age int,
 height int,
 PRIMARY KEY (id)
 )
-""")
+""",
+        )
 
     def _verify_records(self, data):
         conn = self.connect()
@@ -310,27 +348,38 @@ PRIMARY KEY (id)
         cursor = conn.cursor()
 
         data = [(0, "bob", 21, 123), (1, "jim", 56, 45), (2, "fred", 100, 180)]
-        cursor.executemany("insert into bulkinsert (id, name, age, height) "
-                           "values (%s,%s,%s,%s)", data)
+        cursor.executemany(
+            "insert into bulkinsert (id, name, age, height) " "values (%s,%s,%s,%s)",
+            data,
+        )
         self.assertEqual(
-            cursor._last_executed, bytearray(
-            b"insert into bulkinsert (id, name, age, height) values "
-            b"(0,'bob',21,123),(1,'jim',56,45),(2,'fred',100,180)"))
-        cursor.execute('commit')
+            cursor._last_executed,
+            bytearray(
+                b"insert into bulkinsert (id, name, age, height) values "
+                b"(0,'bob',21,123),(1,'jim',56,45),(2,'fred',100,180)"
+            ),
+        )
+        cursor.execute("commit")
         self._verify_records(data)
 
     def test_bulk_insert_multiline_statement(self):
         conn = self.connect()
         cursor = conn.cursor()
         data = [(0, "bob", 21, 123), (1, "jim", 56, 45), (2, "fred", 100, 180)]
-        cursor.executemany("""insert
+        cursor.executemany(
+            """insert
 into bulkinsert (id, name,
 age, height)
 values (%s,
 %s , %s,
 %s )
- """, data)
-        self.assertEqual(cursor._last_executed.strip(), bytearray(b"""insert
+ """,
+            data,
+        )
+        self.assertEqual(
+            cursor._last_executed.strip(),
+            bytearray(
+                b"""insert
 into bulkinsert (id, name,
 age, height)
 values (0,
@@ -339,17 +388,21 @@ values (0,
 'jim' , 56,
 45 ),(2,
 'fred' , 100,
-180 )"""))
-        cursor.execute('commit')
+180 )"""
+            ),
+        )
+        cursor.execute("commit")
         self._verify_records(data)
 
     def test_bulk_insert_single_record(self):
         conn = self.connect()
         cursor = conn.cursor()
         data = [(0, "bob", 21, 123)]
-        cursor.executemany("insert into bulkinsert (id, name, age, height) "
-                           "values (%s,%s,%s,%s)", data)
-        cursor.execute('commit')
+        cursor.executemany(
+            "insert into bulkinsert (id, name, age, height) " "values (%s,%s,%s,%s)",
+            data,
+        )
+        cursor.execute("commit")
         self._verify_records(data)
 
     def test_issue_288(self):
@@ -357,15 +410,21 @@ values (0,
         conn = self.connect()
         cursor = conn.cursor()
         data = [(0, "bob", 21, 123), (1, "jim", 56, 45), (2, "fred", 100, 180)]
-        cursor.executemany("""insert
+        cursor.executemany(
+            """insert
 into bulkinsert (id, name,
 age, height)
 values (%s,
 %s , %s,
 %s ) on duplicate key update
 age = values(age)
- """, data)
-        self.assertEqual(cursor._last_executed.strip(), bytearray(b"""insert
+ """,
+            data,
+        )
+        self.assertEqual(
+            cursor._last_executed.strip(),
+            bytearray(
+                b"""insert
 into bulkinsert (id, name,
 age, height)
 values (0,
@@ -375,17 +434,8 @@ values (0,
 45 ),(2,
 'fred' , 100,
 180 ) on duplicate key update
-age = values(age)"""))
-        cursor.execute('commit')
+age = values(age)"""
+            ),
+        )
+        cursor.execute("commit")
         self._verify_records(data)
-
-    def test_warnings(self):
-        con = self.connect()
-        cur = con.cursor()
-        with warnings.catch_warnings(record=True) as ws:
-            warnings.simplefilter("always")
-            cur.execute("drop table if exists no_exists_table")
-        self.assertEqual(len(ws), 1)
-        self.assertEqual(ws[0].category, pymysql.Warning)
-        if u"no_exists_table" not in str(ws[0].message):
-            self.fail("'no_exists_table' not in %s" % (str(ws[0].message),))
